@@ -3,6 +3,10 @@ from typing import List, Optional, Protocol
 from feeluown.excs import ModelNotFound
 from feeluown.library import (
     AbstractProvider,
+    BriefSongModel,
+    PlaylistModel,
+    Collection,
+    CollectionType,
     ProviderV2,
     ProviderFlags as PF,
     SupportsSongGet,
@@ -17,6 +21,7 @@ from feeluown.library import (
     SupportsArtistGet,
     SupportsPlaylistGet,
     SupportsPlaylistSongsReader,
+    SupportsRecACollectionOfSongs,
     SimpleSearchResult,
     SearchType,
     ModelType,
@@ -42,6 +47,7 @@ class Supports(
     SupportsArtistGet,
     SupportsPlaylistGet,
     SupportsPlaylistSongsReader,
+    SupportsRecACollectionOfSongs,
     Protocol,
 ):
     pass
@@ -247,6 +253,31 @@ class QQProvider(AbstractProvider, ProviderV2):
             pl["logo"] = pl["cover"]
         return [_deserialize(playlist, QQPlaylistSchema) for playlist in playlists]
 
+    def rec_a_collection_of_songs(self):
+        # TODO: cache API result
+        feed = self.api.get_recommend_feed()
+        shelf = None
+        for shelf in feed['v_shelf']:
+            # I guess 10046 means 'song'.
+            if shelf['miscellany'].get('jumptype') == 10046:
+                shelf = shelf
+        if shelf is None:
+            return '', []
+        title = shelf['title_content'] or shelf['title_template']
+        song_ids = []
+        for batch in shelf['v_niche']:
+            for card in batch['v_card']:
+                if card['jumptype'] == 10046:
+                    song_id = int(card['id'])
+                    if song_id not in song_ids:
+                        song_ids.append(song_id)
+
+        tracks = self.api.batch_song_details(song_ids)
+        return Collection(name=title,
+                          type_=CollectionType.only_songs,
+                          models=[_deserialize(track, QQSongSchema) for track in tracks],
+                          description='')
+
     def current_user_get_radio_songs(self):
         songs_data = self.api.get_radio_music()
         return [_deserialize(s, QQSongSchema) for s in songs_data]
